@@ -54,6 +54,7 @@ class CJpegLib:
         Y,
         Cb,
         Cr,
+        K,
         qt,
         quant_tbl_no,
         path=None,
@@ -65,10 +66,12 @@ class CJpegLib:
             Y,
             Cb,
             Cr,
+            K,
             qt,
             quant_tbl_no
         )
         if status == 0:
+            print(f"{path=} {srcfile=}")
             raise IOError(f"reading of {path} DCT failed")
 
     @classmethod
@@ -79,6 +82,7 @@ class CJpegLib:
         Y,
         Cb,
         Cr,
+        K,
         image_dims,
         block_dims,
         in_color_space,
@@ -97,6 +101,7 @@ class CJpegLib:
             Y,
             Cb,
             Cr,
+            K,
             image_dims,
             block_dims,
             in_color_space,
@@ -159,6 +164,7 @@ class CJpegLib:
         qt,
         quality,
         quant_tbl_no,
+        base_quant_tbl_idx,
         smoothing_factor,
         num_markers: int,
         marker_types,
@@ -177,6 +183,7 @@ class CJpegLib:
             qt,
             cls.factor(quality),
             quant_tbl_no,
+            cls.factor(base_quant_tbl_idx),
             cls.factor(smoothing_factor),
             num_markers,
             marker_types,
@@ -185,7 +192,7 @@ class CJpegLib:
             cls.flags_to_mask(flags)
         )
         if status == 0:
-            raise IOError(f"writing RGB to {dstfile} failed")
+            raise IOError(f"writing spatial to {dstfile} failed")
 
     MASKS = {
         "DO_FANCY_SAMPLING": (0b1 << 0),
@@ -212,7 +219,6 @@ class CJpegLib:
         if flags is None:
             return mask
         for flag in flags:
-            # print(f"flag {flag}:")
             # parse sign
             sign = '-' if flag[0] == '-' else '+'
             if not flag[0].isalpha():
@@ -241,7 +247,7 @@ class CJpegLib:
     @classmethod
     def factor(cls, factor):
         if factor is None:
-            factor = 0
+            factor = -1
         return ctypes.c_short(factor)
 
     _lib = None
@@ -268,26 +274,31 @@ class CJpegLib:
         so_files = [
             f
             for f in os.listdir(list(cjpeglib.__path__)[0])
-            if re.fullmatch(r'cjpeglib_.*\..*\.so', f)
+            if re.fullmatch(r'cjpeglib_.*\.(.*\.so|pyd)', f)
         ]
         return so_files
 
     @classmethod
     def versions(cls):
-        vs = [re.search(r'cjpeglib_[^.]*\..*\.so', f) for f in cls._versions()]
-        vs = [v[0] for v in vs if v]
+        # list DLLs
+        vs = [re.search(r'cjpeglib_[^.]*\.(.*\.so|pyd)', f)[0] for f in cls._versions()]
+        # parse versions
+        vs = [re.search(r'(?<=cjpeglib_)[^.]*', f)[0] for f in cls._versions()]
         return vs
 
     @classmethod
     def _bind_lib(cls, version='6b'):
         # path of the library
         so_files = [f for f in cls._versions() if re.fullmatch(
-            f'cjpeglib_{version}' + r'\..*\.so', f)]
+            f'cjpeglib_{version}' + r'\.(.*\.so|pyd)', f)]
         try:
             so_file = so_files[0]
         except IndexError:
-            raise Exception("dynamic library not found")
-        libname = pathlib.Path(list(cjpeglib.__path__)[0]) / so_file
+            so_file = None
+        if so_file is None:
+            raise RuntimeError(f'version "{version}" not found')
+        libname = str(pathlib.Path(list(cjpeglib.__path__)[0]) / so_file)
+        # libname = str(os.path.join(list(cjpeglib.__path__)[0], so_file))
         # connect
         cjpeglib_dylib = ctypes.CDLL(libname)
         cls.version = version
