@@ -8,7 +8,8 @@ from ._bind import CJpegLib
 from ._colorspace import Colorspace
 from ._marker import Marker
 
-MAX_MARKER:int = 50
+MAX_MARKER: int = 50
+
 
 @dataclasses.dataclass
 class JPEG:
@@ -124,6 +125,24 @@ class JPEG:
         """
         return self.num_components > 1
 
+    @property
+    def has_black(self) -> bool:
+        """Indicator of presence of fourth, black channel.
+
+        :return: True for YCCK/CMYK image, False for simple grayscale/color image
+        :rtype: bool
+
+        :Example:
+
+        >>> im = jpeglib.read_spatial("rgb.jpeg")
+        >>> im.has_chrominance # -> False
+
+        >>> im = jpeglib.read_spatial("cmyk.jpeg")
+        >>> im.has_chrominance # -> True
+
+        """
+        return self.num_components > 3
+
     @property
     def num_components(self) -> int:
         """Getter of number of color components in the JPEG.
@@ -236,10 +255,10 @@ class JPEG:
 def load_jpeg_info(path: str) -> JPEG:
     """"""
     # allocate
-    _block_dims = (ctypes.c_int*6)()
+    _block_dims = (ctypes.c_int*8)()
+    _samp_factor = (ctypes.c_int*8)()
     _image_dims = (ctypes.c_int*2)()
     _num_components = (ctypes.c_int*1)()
-    _samp_factor = (ctypes.c_int*6)()
     _jpeg_color_space = (ctypes.c_int*2)()
     _marker_lengths = (ctypes.c_int*MAX_MARKER)()
     _marker_types = (ctypes.c_uint32*MAX_MARKER)()
@@ -260,11 +279,13 @@ def load_jpeg_info(path: str) -> JPEG:
     # process
     num_components = _num_components[0]  # number of components in JPEG
     block_dims = (
-        np.array([_block_dims[i] for i in range(2*num_components)], int)
-        .reshape(num_components, 2))
+        np.array([_block_dims[i] for i in range(2*num_components)], 'int32')
+        .reshape(num_components, 2)
+    )
     samp_factor = (
-        np.array([_samp_factor[i] for i in range(2*num_components)], int)
-        .reshape(num_components, 2))
+        np.array([_samp_factor[i] for i in range(2*num_components)], 'int32')
+        .reshape(num_components, 2)
+    )
     markers = []
     for i in range(MAX_MARKER):
         # marker length
