@@ -1,7 +1,17 @@
+#ifndef CJPEGLIB_H
+#define CJPEGLIB_H
+
+#ifdef _WIN32
+#define LIBRARY_API extern "C" __declspec(dllexport)
+#else
+#define LIBRARY_API extern "C"
+#endif
+
+
+#include "cjpeglib_common_flags.h"
 
 // ---------- Meta -------------
-typedef unsigned long BITMASK;
-
+LIBRARY_API
 int read_jpeg_info(
     const char *srcfile,
     int *block_dims,
@@ -11,26 +21,34 @@ int read_jpeg_info(
     int *jpeg_color_space,
     int *marker_lengths,
     int *mark_types,
-    BITMASK *flags);
+    BITMASK *flags
+);
 
+LIBRARY_API
 int read_jpeg_markers(
     const char *srcfile,
-    unsigned char *markers);
+    unsigned char *markers
+);
 
 // ----------- DCT -------------
+LIBRARY_API
 int read_jpeg_dct(
     const char *srcfile,
     short *Y,
     short *Cb,
     short *Cr,
+    short *K,
     unsigned short *qt,
-    unsigned char *quant_tbl_no);
+    unsigned char *quant_tbl_no
+);
+LIBRARY_API
 int write_jpeg_dct(
     const char *srcfile,
     const char *dstfile,
     short *Y,
     short *Cb,
     short *Cr,
+    short *K,
     int *image_dims,
     int *block_dims,
     int in_color_space,
@@ -41,9 +59,11 @@ int write_jpeg_dct(
     int num_markers,
     int *marker_types,
     int *marker_lengths,
-    unsigned char *markers);
+    unsigned char *markers
+);
 
 // ----------- RGB -------------
+LIBRARY_API
 int read_jpeg_spatial(
     const char *srcfile,
     unsigned char *rgb,
@@ -52,8 +72,10 @@ int read_jpeg_spatial(
     int out_color_space,
     int dither_mode,
     int dct_method,
-    BITMASK flags);
+    BITMASK flags
+);
 
+LIBRARY_API
 int write_jpeg_spatial(
     const char *dstfile,
     unsigned char *rgb,
@@ -65,12 +87,18 @@ int write_jpeg_spatial(
     unsigned short *qt,
     short quality,
     short *quant_tbl_no,
+    short base_quant_tbl_idx,
     short smoothing_factor,
     int num_markers,
     int *marker_types,
     int *marker_lengths,
     unsigned char *markers,
-    BITMASK flags);
+    BITMASK flags
+);
 
 // int jpeg_lib_version(void) { return JPEG_LIB_VERSION; }
+LIBRARY_API
 int print_jpeg_params(const char *srcfile);
+
+
+#endif // CJPEGLIB_H
\ No newline at end of file
