@@ -56,6 +56,7 @@ def read_dct(
     path = str(path)
     with open(path, "rb") as f:
         content = f.read()
+        f.flush()
     # load info
     info = _jpeg.load_jpeg_info(path)
     # create jpeg
@@ -73,6 +74,7 @@ def read_dct(
         Y=None,
         Cb=None,
         Cr=None,
+        K=None,
         qt=None,
         progressive_mode=info.progressive_mode
     )
@@ -81,8 +83,8 @@ def read_dct(
 def read_spatial(
     path: str,
     out_color_space: str = None,
-    dither_mode: str = None,
-    dct_method: str = None,
+    dct_method: typing.Union[str, DCTMethod] = None,
+    dither_mode: typing.Union[str, Dithermode] = None,
     flags: list = []
 ) -> SpatialJPEG:
     """Function for decompressing the JPEG as a pixel data (spatial domain).
@@ -139,16 +141,14 @@ def read_spatial(
         out_color_space = Colorspace(out_color_space)
         jpeg_color_space = out_color_space
     else:
-        out_color_space = Colorspace(
-            'JCS_RGB' if info.has_chrominance else 'JCS_GRAYSCALE'
-        )
+        if info.has_black:
+            out_color_space = 'JCS_CMYK'
+        else:
+            out_color_space = 'JCS_RGB' if info.has_chrominance else 'JCS_GRAYSCALE'
+        out_color_space = Colorspace(out_color_space)
 
-    if dct_method is not None:
-        dct_method = DCTMethod(dct_method)
-    if dither_mode is not None:
-        dither_mode = Dithermode(dither_mode)
     # create jpeg
-    return SpatialJPEG(
+    im = SpatialJPEG(
         path=path,
         content=content,
         height=info.height,
@@ -160,11 +160,24 @@ def read_spatial(
         markers=info.markers,
         spatial=None,
         color_space=out_color_space,
-        dither_mode=dither_mode,
-        dct_method=dct_method,
+        # dither_mode=dither_mode,
+        # dct_method=dct_method,
         flags=flags,
         progressive_mode=info.progressive_mode
     )
+    if dct_method is not None or dither_mode is not None:
+        # parse inputs
+        if dct_method is not None:
+            dct_method = DCTMethod.parse_input(dct_method)
+        if dither_mode is not None:
+            dither_mode = Dithermode.parse_input(dither_mode)
+        # load image data
+        im.load(
+            dct_method=dct_method,
+            dither_mode=dither_mode
+        )
+    return im
+
 
 
 def from_spatial(
@@ -226,22 +239,29 @@ def from_spatial(
     height, width, num_components = spatial.shape
     # parse colorspace
     if in_color_space is not None:
-        try:
+        if not isinstance(in_color_space, Colorspace):
             cspace = Colorspace(in_color_space)
             cspace.index
             in_color_space = cspace
-        except KeyError:
-            in_color_space = in_color_space
     # infere colorspace
     if in_color_space is None:
         if num_components == 3:
             in_color_space = Colorspace('JCS_RGB')
-            jpeg_color_space = Colorspace('JCS_YCbCr')
+            # jpeg_color_space = Colorspace('JCS_YCbCr')
         elif num_components == 1:
             in_color_space = Colorspace('JCS_GRAYSCALE')
-            jpeg_color_space = Colorspace('JCS_GRAYSCALE')
+            # jpeg_color_space = Colorspace('JCS_GRAYSCALE')
         else:
             raise IOError('failed to infere colorspace')
+    if in_color_space == Colorspace('JCS_GRAYSCALE'):
+        jpeg_color_space = Colorspace('JCS_GRAYSCALE')
+    elif in_color_space == Colorspace('JCS_CMYK'):
+        jpeg_color_space = Colorspace('JCS_YCCK')
+    else:
+        jpeg_color_space = Colorspace('JCS_YCbCr')
+    # else:
+    #     raise IOError('failed to infere colorspace')
+
     # create jpeg
     return SpatialJPEG(
         path=None,
@@ -254,8 +274,6 @@ def from_spatial(
         markers=None,
         spatial=spatial,
         color_space=in_color_space,
-        dither_mode=None,
-        dct_method=None,
         flags=[],
         progressive_mode=None
     )
@@ -265,6 +283,7 @@ def from_dct(
     Y: np.ndarray,
     Cb: np.ndarray = None,
     Cr: np.ndarray = None,
+    K: np.ndarray = None,
     qt: np.ndarray = None,
     quant_tbl_no: list = None,
 ) -> DCTJPEG:
@@ -289,6 +308,8 @@ def from_dct(
     :type Cb: np.ndarray
     :param Cr: Red chrominance tensor.
     :type Cr: np.ndarray
+    :param K: Black tensor.
+    :type K: np.ndarray
     :param qt: Quantization table tensor.
     :type qt: np.ndarray
 
@@ -324,7 +345,10 @@ def from_dct(
     """
     # infere colorspace
     if Cb is not None and Cr is not None:
-        jpeg_color_space = Colorspace('JCS_YCbCr')
+        if K is not None:
+            jpeg_color_space = Colorspace('JCS_YCCK')
+        else:
+            jpeg_color_space = Colorspace('JCS_YCbCr')
     elif Cb is None and Cr is None:
         # jpeg_color_space = Colorspace('JCS_YCbCr')  # only Y
         jpeg_color_space = Colorspace('JCS_GRAYSCALE')
@@ -345,12 +369,14 @@ def from_dct(
             quant_tbl_no = np.array([0])
     # infere samp_factor
     # TODO
-    samp_factor = ((1, 1), (1, 1), (1, 1))
+    samp_factor = ((1, 1), (1, 1), (1, 1), (1, 1))
     # block dims
     block_dims = [[Y.shape[0], Y.shape[1]]]
     if Cb is not None and Cr is not None:
         block_dims.append([Cb.shape[0], Cb.shape[1]])
         block_dims.append([Cr.shape[0], Cr.shape[1]])
+    if K is not None:
+        block_dims.append([K.shape[0], K.shape[1]])
     block_dims = np.array(block_dims)
 
     # create jpeg
@@ -368,6 +394,7 @@ def from_dct(
         Y=Y,
         Cb=Cb,
         Cr=Cr,
+        K=None,
         qt=qt,
         progressive_mode=None,
     )
